/* manabe_liebe_hufford.c - calculate dielectric constant of liquid water */
/* Uses the "Double Debye" formula of Manabe, Liebe and Hufford (1987) */

#include "attenuation.h"

acomplex
manabe_liebe_hufford_dielectric(afloat temperature_K,
				afloat frequency_GHz)
{
  afloat pi = 3.14159265358;

  afloat theta_1 = 300.0 / temperature_K - 1.0;
  afloat omega = 2.0 * pi * frequency_GHz * 1.0e9;

  afloat tau1 = omega * 1.0e-12
    / (2.0 * pi * (0.02009 + theta_1 * (-0.1424 + 0.294 * theta_1)));
  afloat tau2 = omega * 1.0e-12
    / (2.0 * pi * (0.59 - theta_1 * 1.5));

  afloat e1 = 77.66 + 103.3 * theta_1;
  afloat e2 = 5.48;
  afloat e3 = 3.51;

  acomplex e;

  e.r = (e1 - e2) / (1.0 + tau1 * tau1)
    + (e2 - e3) / (1.0 + tau2 * tau2) + e3;
  e.i = -(e1 - e2) * tau1 / (1.0 + tau1 * tau1)
    + (e2 - e3) * tau2 / (1.0 + tau2 * tau2);

  return e;
}
